# Readme

Different scripts, which can be useful for HTCondor in various ways.
Refer to the [HTCondor documentation](http://research.cs.wisc.edu/htcondor/manual/) how those scripts are invoked in detail.

In general they can be used by one of the following commands.
```
include command : *command*
include : *script* |
```
Refer to the scripts' documentation string and/or inline code documentation for further information.

* * *

## Automatic configuration via GIT:
Pull configuration files from a remote git repository.
Inspired by an [HTCondorWeek2016 presentation](https://research.cs.wisc.edu/htcondor/HTCondorWeek2016/presentations/Grasmick_GitConfig.pdf) by Erin Grasmick.
Of course you need **Git** installed on the system...

* `config_pull.py`
* `config_sites.json`
    * Contains information which sites use which configuration file(s).

### Setup:
For an easy condor setup, you can manually checkout these 2 files into a single folder and execute `./config_pull.py sitename`.

### Usage for auto pull:
1. the following has to be added to `/etc/sudoers.d/condor_git_config`:
    ```
    condor ALL=(root) NOPASSWD: /etc/condor/config_pull.py
    Defaults!/etc/condor/config_pull.py !requiretty
    ```
2. the following has to be added to `/etc/condor/condor_config`:
    ```
    if $(IsMaster)
        include : /etc/condor/sitename
        # pull config from git and update Master attribute GitHead
        include command : python /etc/condor/config_pull.py $(JsonSite)
    endif
    ```
    With this configuration, restarting HTCondor will cause the machine to `git pull` from the repository.

    Furthermore you can check your machines' configuration status with
    ```
    condor_status -master -const '!IsUndefined(GitHead)' -af name githead
    ```
3. Create a file `/etc/condor/sitename` and write in it the corresponding key name from `config_sites.json`, e.g.:
    ```
    JsonSite=EkpDocker
    ```
## Read walltime information
* `get_walltime.sh`
* `meta_walltime.py`

There are 2 ways to import scheduling/walltime information into a machine:
* Dump a machine's wall time (in unix time) into a file at boot time.  
  The file's creation time will be used to determine the machine's boot time.
* Supply scheduling information as metadata to cloud-init.
  * This script additionally adds the information to `/etc/environment`.

These 2 scripts can be used to read the information and make it usable in HTCondor.

## Machine environment
By default, HTCondor sets almost no environment variables. Thus they aren't forwarded to job environments by default.

`get_machine_env.sh` parses `/etc/environment` and prints the statement in a format, that HTCondor accepts. The information is stored in the variable `STARTER_JOB_ENVIRONMENT`.

Add the following line to the configuration file, to propagate the information to the single jobs:
```
JOB_INHERITS_STARTER_ENVIRONMENT = TRUE
```
## Automatic shutdown
* `shutdown.sh`

Determine the shutdown reason and shut down (with 1 minute delay).  
Originally from the [HTCondor Wiki](https://htcondor-wiki.cs.wisc.edu/index.cgi/wiki?p=HowToShutdownAnIdleMachine).

### Configuration
To automatically shut down a virtual machine when condor is idle for 7 minutes, you can simply add the configuration file `0085.auto_shutdown.cfg`:
